;;; DO NOT MODIFY THIS FILE
(if (featurep 'xlib-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "lisp/_pkg.el")

(package-provide 'xlib :version 1.12 :author-version "0.2" :type 'regular)

;;;***

;;;### (autoloads nil "xlib-const" "lisp/xlib-const.el")

(defconst xlib-version "xlib(xemacs-package): $Revision: 1.4 $")

(defconst X-False 0 "\
False")

(defconst X-True 1 "\
True")

(defconst X-CopyFromParent 0 "\
CopyFromParent opcode.")

(defconst X-InputOutput 1 "\
InputOutput opcode.")

(defconst X-InputOnly 2 "\
InputOnly opcode.")

(defconst X-Unmap 0 "\
Unmap gravity.")

(defconst X-NorthWest 1 "\
NorthWest gravity.")

(defconst X-North 2 "\
North gravity.")

(defconst X-NorthEast 3 "\
NorthEast gravity.")

(defconst X-West 4 "\
West gravity.")

(defconst X-Center 5 "\
Center gravity.")

(defconst X-East 6 "\
East gravity.")

(defconst X-SouthWest 7 "\
SouthWest gravity.")

(defconst X-South 8 "\
South gravity.")

(defconst X-SouthEast 9 "\
SouthEast gravity.")

(defconst X-Static 10 "\
Static gravity.")

(defconst X-NotUseful 0 "\
NotUseful backing store.")

(defconst X-WhenMapped 1 "\
WhenMapped backing store.")

(defconst X-Always 2 "\
Always backing store.")

(defconst XM-NoEvent 0 "\
No Event mask.")

(defconst XM-KeyPress 1 "\
KeyPress bitmask.")

(defconst XM-KeyRelease 2 "\
KeyRelease bitmask.")

(defconst XM-ButtonPress 4 "\
ButtonPress bitmask.")

(defconst XM-ButtonRelease 8 "\
ButtonRelease bitmask.")

(defconst XM-EnterWindow 16 "\
EnterWindow bitmask.")

(defconst XM-LeaveWindow 32 "\
LeaveWindow bitmask.")

(defconst XM-PointerMotion 64 "\
PointerMotion bitmask.")

(defconst XM-PointerMotionHint 128 "\
PointerMotionHint bitmask.")

(defconst XM-Button1Motion 256 "\
Button2Motion bitmask.")

(defconst XM-Button2Motion 512 "\
Button2Motion bitmask.")

(defconst XM-Button3Motion 1024 "\
Button3Motion bitmask.")

(defconst XM-Button4Motion 2048 "\
Button4Motion bitmask.")

(defconst XM-Button5Motion 4096 "\
Button5Motion bitmask.")

(defconst XM-ButtonMotion 8192 "\
Button bitmask.")

(defconst XM-KeymapState 16384 "\
KeymapState bitmask.")

(defconst XM-Exposure 32768 "\
Exposure bitmask.")

(defconst XM-VisibilityChange 65536 "\
VisibilityChange bitmask.")

(defconst XM-StructureNotify 131072 "\
StructureNotify bitmask.")

(defconst XM-ResizeRedirect 262144 "\
ResizeRedirect bitmask.")

(defconst XM-SubstructureNotify 524288 "\
SubstructureNotify bitmask.")

(defconst XM-SubstructureRedirect 1048576 "\
SubstructureRedirect bitmask.")

(defconst XM-FocusChange 2097152 "\
FocusChange bitmask.")

(defconst XM-PropertyChange 4194304 "\
PropertyChange bitmask.")

(defconst XM-ColormapChange 8388608 "\
ColormapChange bitmask.")

(defconst XM-OwnerGrabButton 16777216 "\
OwnerGrabButton bitmask.")

(defconst X-SyntheticMask 128 "\
Mask the synthetic part off.")

(defconst X-KeyPress 2 "\
KeyPress event.")

(defconst X-KeyRelease 3 "\
KeyRelease event.")

(defconst X-ButtonPress 4 "\
ButtonPress event.")

(defconst X-ButtonRelease 5 "\
ButtonRelease event.")

(defconst X-MotionNotify 6 "\
MotionNotify event.")

(defconst X-EnterNotify 7 "\
EnterNotify event.")

(defconst X-LeaveNotify 8 "\
LeaveNotify event.")

(defconst X-FocusIn 9 "\
FocusIn event.")

(defconst X-FocusOut 10 "\
FocusOut event.")

(defconst X-KeymapNotify 11 "\
KeymapNotify event.")

(defconst X-Expose 12 "\
Expose event.")

(defconst X-GraphicsExpose 13 "\
GraphicsExpose event.")

(defconst X-NoExpose 14 "\
NoExpose event.")

(defconst X-VisibilityNotify 15 "\
VisibilityNotify event.")

(defconst X-CreateNotify 16 "\
CreateNotify event.")

(defconst X-DestroyNotify 17 "\
DestroyNotify event.")

(defconst X-UnmapNotify 18 "\
UnmapNotify event.")

(defconst X-MapNotify 19 "\
MapNotify event.")

(defconst X-MapRequest 20 "\
MapRequest event.")

(defconst X-ReparentNotify 21 "\
ReparentNotify event.")

(defconst X-ConfigureNotify 22 "\
ConfigureNotify event.")

(defconst X-ConfigureRequest 23 "\
ConfigureRequest event.")

(defconst X-GravityNotify 24 "\
GravityNotify event.")

(defconst X-ResizeRequest 25 "\
ResizeRequest event.")

(defconst X-CirculateNotify 26 "\
CirculateNotify event.")

(defconst X-CirculateRequest 27 "\
CirculateRequest event.")

(defconst X-PropertyNotify 28 "\
PropertyNotify event.")

(defconst X-SelectionClear 29 "\
SelectionClear event.")

(defconst X-SelectionRequest 30 "\
SelectionRequest event.")

(defconst X-SelectionNotify 31 "\
SelectionNotify event.")

(defconst X-ColormapNotify 32 "\
ColormapNotify event.")

(defconst X-ClientMessage 33 "\
ClientMessage event.")

(defconst X-MappingNotify 34 "\
MappingNotify event.")

(defconst X-MaxEvent 35 "\
1 greater than the largest event opcode.")

(defconst X-PropertyNewValue 0)

(defconst X-PropertyDelete 1)

(defconst X-Above 0 "\
Stacking mode Above.")

(defconst X-Below 1 "\
Stacking mode Below.")

(defconst X-TopIf 2 "\
Stacking mode TopIf.")

(defconst X-BottomIf 3 "\
Stacking mode BottomIf.")

(defconst X-Opposite 4 "\
Stacking mode Opposite.")

(defconst X-format-8 8 "\
8 bit formatting for Atoms.")

(defconst X-format-16 16 "\
16 bit formatting for Atoms.")

(defconst X-format-32 32 "\
32 bit formatting for Atoms.")

(autoload 'make-X-Atom "xlib-xwin")

(defconst XA-AnyPropertyType (make-X-Atom :id 0.0 :name "") "\
Any atom.")

(defconst XA-primary (make-X-Atom :id 1.0 :name "PRIMARY") "\
Atom primary encoding.")

(defconst XA-secondary (make-X-Atom :id 2.0 :name "SECONDARY") "\
Atom secondary encoding.")

(defconst XA-arc (make-X-Atom :id 3.0 :name "ARC") "\
Atom arc encoding.")

(defconst XA-atom (make-X-Atom :id 4.0 :name "ATOM") "\
Atom atom encoding.")

(defconst XA-bitmap (make-X-Atom :id 5.0 :name "BITMAP") "\
Atom bitmap encoding.")

(defconst XA-cardinal (make-X-Atom :id 6.0 :name "CARDINAL") "\
Atom cardinal encoding.")

(defconst XA-colormap (make-X-Atom :id 7.0 :name "COLORMAP") "\
Atom colormap encoding.")

(defconst XA-cursor (make-X-Atom :id 8.0 :name "CURSOR") "\
Atom cursor encoding.")

(defconst XA-cut-buffer0 (make-X-Atom :id 9.0 :name "XA-CUT-BUFFER0") "\
Atom cut-buffer0 encoding.")

(defconst XA-cut-buffer1 (make-X-Atom :id 10.0 :name "CUT-BUFFER1") "\
Atom cut-buffer1 eoncoding.")

(defconst XA-cut-buffer2 (make-X-Atom :id 11.0 :name "CUT-BUFFER2") "\
Atom cut-buffer2 eoncoding.")

(defconst XA-cut-buffer3 (make-X-Atom :id 12.0 :name "CUT-BUFFER3") "\
Atom cut-buffer3 eoncoding.")

(defconst XA-cut-buffer4 (make-X-Atom :id 13.0 :name "CUT-BUFFER4") "\
Atom cut-buffer4 eoncoding.")

(defconst XA-cut-buffer5 (make-X-Atom :id 14.0 :name "CUT-BUFFER5") "\
Atom cut-buffer5 eoncoding.")

(defconst XA-cut-buffer6 (make-X-Atom :id 15.0 :name "CUT-BUFFER6") "\
Atom cut-buffer6 eoncoding.")

(defconst XA-cut-buffer7 (make-X-Atom :id 16.0 :name "CUT-BUFFER7") "\
Atom cut-buffer7 eoncoding.")

(defconst XA-drawable (make-X-Atom :id 17.0 :name "XA-DRAWABLE") "\
Atom drawable eoncoding.")

(defconst XA-font (make-X-Atom :id 18.0 :name "FONT") "\
Atom font eoncoding.")

(defconst XA-integer (make-X-Atom :id 19.0 :name "INTEGER") "\
Atom integer eoncoding.")

(defconst XA-pixmap (make-X-Atom :id 20.0 :name "PIXMAP") "\
Atom pixmap eoncoding.")

(defconst XA-point (make-X-Atom :id 21.0 :name "POINT") "\
Atom point eoncoding.")

(defconst XA-rectangle (make-X-Atom :id 22.0 :name "RECTANGLE") "\
Atom rectangle eoncoding.")

(defconst XA-resource-manager (make-X-Atom :id 23.0 :name "RESOURCE-MANAGER") "\
Atom resource-manager eoncoding.")

(defconst XA-rgb-color-map (make-X-Atom :id 24.0 :name "RGB-COLOR-MAP") "\
Atom rgb-color-map eoncoding.")

(defconst XA-rgb-best-map (make-X-Atom :id 25.0 :name "RGB-BEST-MAP") "\
Atom rgb-best-map eoncoding.")

(defconst XA-rgb-blue-map (make-X-Atom :id 26.0 :name "RGB-BLUE-MAP") "\
Atom rgb-blue-map eoncoding.")

(defconst XA-rgb-default-map (make-X-Atom :id 27.0 :name "RGB-DEFAULT-MAP") "\
Atom rgb-default-map eoncoding.")

(defconst XA-rgb-gray-map (make-X-Atom :id 28.0 :name "RGB-GRAY-MAP") "\
Atom rgb-gray-map eoncoding.")

(defconst XA-rgb-green-map (make-X-Atom :id 29.0 :name "RGB-GREEN-MAP") "\
Atom rgb-green-map eoncoding.")

(defconst XA-rgb-red-map (make-X-Atom :id 30.0 :name "RGB-RED-MAP") "\
Atom rgb-red-map eoncoding.")

(defconst XA-string (make-X-Atom :id 31.0 :name "STRING") "\
Atom string eoncoding.")

(defconst XA-visualid (make-X-Atom :id 32.0 :name "VISUALID") "\
Atom visualid eoncoding.")

(defconst XA-window (make-X-Atom :id 33.0 :name "WINDOW") "\
Atom window eoncoding.")

(defconst XA-wm-command (make-X-Atom :id 34.0 :name "WM-COMMAND") "\
Atom wm-command eoncoding.")

(defconst XA-wm-hints (make-X-Atom :id 35.0 :name "WM-HINTS") "\
Atom wm-hints eoncoding.")

(defconst XA-wm-client-machine (make-X-Atom :id 36.0 :name "WM-CLIENT-MACHINE") "\
Atom wm-client-machine eoncoding.")

(defconst XA-wm-icon-name (make-X-Atom :id 37.0 :name "WM-ICON-NAME") "\
Atom wm-icon-name eoncoding.")

(defconst XA-wm-icon-size (make-X-Atom :id 38.0 :name "WM-ICON-SIZE") "\
Atom wm-icon-size eoncoding.")

(defconst XA-wm-name (make-X-Atom :id 39.0 :name "WM-NAME") "\
Atom wm-name eoncoding.")

(defconst XA-wm-normal-hints (make-X-Atom :id 40.0 :name "WM-NORMAL-HINTS") "\
Atom wm-normal-hints eoncoding.")

(defconst XA-wm-size-hints (make-X-Atom :id 41.0 :name "WM-SIZE-HINTS") "\
Atom wm-size-hints eoncoding.")

(defconst XA-wm-zoom-hints (make-X-Atom :id 42.0 :name "WM-ZOOM-HINTS") "\
Atom wm-zoom-hints eoncoding.")

(defconst XA-min-space (make-X-Atom :id 43.0 :name "MIN-SPACE") "\
Atom min-space eoncoding.")

(defconst XA-norm-space (make-X-Atom :id 44.0 :name "NORM-SPACE") "\
Atom norm-space eoncoding.")

(defconst XA-max-space (make-X-Atom :id 45.0 :name "MAX-SPACE") "\
Atom max-space eoncoding.")

(defconst XA-end-space (make-X-Atom :id 46.0 :name "END-SPACE") "\
Atom end-space eoncoding.")

(defconst XA-superscript-x (make-X-Atom :id 47.0 :name "SUPERSCRIPT-X") "\
Atom superscript-x eoncoding.")

(defconst XA-superscript-y (make-X-Atom :id 48.0 :name "SUPERSCRIPT-Y") "\
Atom superscript-y eoncoding.")

(defconst XA-subscript-x (make-X-Atom :id 49.0 :name "SUBSCRIPT-X") "\
Atom subscript-x eoncoding.")

(defconst XA-subscript-y (make-X-Atom :id 50.0 :name "SUBSCRIPT-Y") "\
Atom subscript-y eoncoding.")

(defconst XA-underline-position (make-X-Atom :id 51.0 :name "UNDERLINE-POSITION") "\
Atom underline-position eoncoding.")

(defconst XA-underline-thickness (make-X-Atom :id 52.0 :name "UNDERLINE-THICKNESS") "\
Atom underline-thickness eoncoding.")

(defconst XA-strikeout-ascent (make-X-Atom :id 53.0 :name "STRIKEOUT-ASCENT") "\
Atom strikeout-ascent eoncoding.")

(defconst XA-strikeout-descent (make-X-Atom :id 54.0 :name "STRIKEOUT-DESCENT") "\
Atom strikeout-descent eoncoding.")

(defconst XA-italic-angle (make-X-Atom :id 55.0 :name "ITALIC-ANGLE") "\
Atom italic-angle eoncoding.")

(defconst XA-x-height (make-X-Atom :id 56.0 :name "X-HEIGHT") "\
Atom x-height eoncoding.")

(defconst XA-quad-width (make-X-Atom :id 57.0 :name "QUAD-WIDTH") "\
Atom quad-width eoncoding.")

(defconst XA-weight (make-X-Atom :id 58.0 :name "WEIGHT") "\
Atom weight eoncoding.")

(defconst XA-point-size (make-X-Atom :id 59.0 :name "POINT-SIZE") "\
Atom point-size eoncoding.")

(defconst XA-resolution (make-X-Atom :id 60.0 :name "RESOLUTION") "\
Atom resolution eoncoding.")

(defconst XA-copyright (make-X-Atom :id 61.0 :name "COPYRIGHT") "\
Atom copyright eoncoding.")

(defconst XA-notice (make-X-Atom :id 62.0 :name "NOTICE") "\
Atom notice eoncoding.")

(defconst XA-font-name (make-X-Atom :id 63.0 :name "FONT-NAME") "\
Atom font-name eoncoding.")

(defconst XA-family-name (make-X-Atom :id 64.0 :name "FAMILY-NAME") "\
Atom family-name eoncoding.")

(defconst XA-full-name (make-X-Atom :id 65.0 :name "FULL-NAME") "\
Atom full-name eoncoding.")

(defconst XA-cap-height (make-X-Atom :id 66.0 :name "CAP-HEIGHT") "\
Atom cap-height eoncoding.")

(defconst XA-wm-class (make-X-Atom :id 67.0 :name "WM-CLASS") "\
Atom wm-class eoncoding.")

(defconst XA-wm-transient-for (make-X-Atom :id 68.0 :name "WM-TRANSIENT-FOR") "\
Atom wm-transient-for eoncoding.")

(defconst X-PropModeReplace 0 "\
Property Mode Replace")

(defconst X-PropModePrepend 1 "\
Property Mode Prepend")

(defconst X-PropModeAppend 2 "\
Property Mode Append")

(defconst X-Shift 1 "\
Shift bitmask.")

(defconst X-Lock 2 "\
Lock bitmask.")

(defconst X-Control 4 "\
Control bitmask.")

(defconst X-Mod1 8 "\
Mod1 bitmask.")

(defconst X-Mod2 16 "\
Mod2 bitmask.")

(defconst X-Mod3 32 "\
Mod3 bitmask.")

(defconst X-Mod4 64 "\
Mod4 bitmask.")

(defconst X-Mod5 128 "\
Mod5 bitmask.")

(defconst X-Button1 256 "\
Button1 bitmask.")

(defconst X-Button2 512 "\
Button2 bitmask.")

(defconst X-Button3 1024 "\
Button3 bitmask.")

(defconst X-Button4 2048 "\
Button4 bitmask.")

(defconst X-Button5 4096 "\
Button5 bitmask.")

(defconst X-XButton1 1)

(defconst X-XButton2 2)

(defconst X-XButton3 3)

(defconst X-XButton4 4)

(defconst X-XButton5 5)

(defconst X-GXClear 0 "\
GC function type id.")

(defconst X-GXAnd 1 "\
GC function type id.")

(defconst X-GXAndReverse 2 "\
GC function type id.")

(defconst X-GXCopy 3 "\
GC function type id.")

(defconst X-GXAndInverted 4 "\
GC function type id.")

(defconst X-GXNoOp 5 "\
GC function type id.")

(defconst X-GXXor 6 "\
GC function type id.")

(defconst X-GXOr 7 "\
GC function type id.")

(defconst X-GXNor 8 "\
GC function type id.")

(defconst X-GXEquiv 9 "\
GC function type id.")

(defconst X-GXInvert 10 "\
GC function type id.")

(defconst X-GXOrReverse 11 "\
GC function type id.")

(defconst X-GXCopyInverted 12 "\
GC function type id.")

(defconst X-GXOrInverted 13 "\
GC function type id.")

(defconst X-GXNand 14 "\
GC function type id.")

(defconst X-GXSet 15 "\
GC function type id.")

(defconst X-LineSolid 0 "\
GC line-style.")

(defconst X-LineOnOffDash 1 "\
GC line-style.")

(defconst X-LineDoubleDash 2 "\
GC line-style.")

(defconst X-CapNotLast 0 "\
GC cap-styles.")

(defconst X-CapButt 1 "\
GC cap-styles.")

(defconst X-CapRound 2 "\
GC cap-styles.")

(defconst X-CapProjecting 3 "\
GC cap-styles.")

(defconst X-JoinMiter 0 "\
GC join-style.")

(defconst X-JoinRound 1 "\
GC join-style.")

(defconst X-JoinBevel 2 "\
GC join-style.")

(defconst X-FillSolid 0 "\
GC fill-style.")

(defconst X-FillTiled 1 "\
GC fill-style.")

(defconst X-FillStippled 2 "\
GC fill-style.")

(defconst X-FillOpaqueStippled 3 "\
GC fill-style.")

(defconst X-EvenOddRule 0 "\
GC fill-rule.")

(defconst X-WindingRule 1 "\
GC fill-rule.")

(defconst X-ArcChord 0 "\
GC arc mode.")

(defconst X-ArcPieSlice 1 "\
GC arc mode.")

(defconst X-ClipByChildren 0 "\
GC subwindow-mode.")

(defconst X-IncludeInferiors 1 "\
GC subwindow-mode.")

(defconst X-UnSorted 0 "\
Unsorted list.")

(defconst X-YSorted 1 "\
Sorted by Y.")

(defconst X-YXSorted 2 "\
Sorted by X and Y.")

(defconst X-YXBanded 3)

(defconst X-XYBitmap 0)

(defconst X-XYPixmap 1)

(defconst X-ZPixmap 2)

(defconst X-AllocNone 0 "\
No color entries writable.")

(defconst X-AllocAll 1 "\
All color entries writable.")

(defconst X-DoRed 1 "\
Do Red mask.")

(defconst X-DoGreen 2 "\
Do Green mask.")

(defconst X-DoBlue 4 "\
Do blue mask.")

(defconst X-DoRedGreenBlue 7 "\
All Color Dos ored together.")

(defconst X-Origin 0 "\
Specifies point drawn with relation to origin.")

(defconst X-Previous 1 "\
Specifies points draw with relation to previous point.")

(defconst X-Complex 0)

(defconst X-Nonconvex 1)

(defconst X-Convex 2)

(defconst X-None 0 "\
universal null resource or null atom")

(defconst X-RevertToNone 0 "\
for XSetInputFocus")

(defconst X-RevertToPointerRoot 1 "\
for XSetInputFocus")

(defconst X-RevertToParent 2 "\
for XSetInputFocus")

(defconst X-ParentRelative 1 "\
Background pixmap in CreateWindow and ChangeWindowAttributes.")

(defconst X-CopyFromParent 0 "\
Border pixmap in CreateWindow and ChangeWindowAttributes special
  VisualID and special window class passed to CreateWindow.")

(defconst X-PointerWindow 0 "\
destination window in SendEvent")

(defconst X-InputFocus 1 "\
destination window in SendEvent")

(defconst X-PointerRoot 1 "\
focus window in SetInputFocus")

(defconst X-AnyPropertyType 0 "\
special Atom, passed to GetProperty")

(defconst X-AnyKey 0 "\
special Key Code, passed to GrabKey")

(defconst X-AnyButton 0 "\
special Button Code, passed to GrabButton")

(defconst X-AllTemporary 0 "\
special Resource ID passed to KillClient")

(defconst X-CurrentTime 0 "\
special Time")

(defconst X-NoSymbol 0 "\
special KeySym")

(defconst X-GrabModeSync 0 "\
specific mode")

(defconst X-GrabModeAsync 1 "\
specific mode")

(defconst X-AllPlanes -1 "\
Mask for all planes in XGetImage.")

(defconst X-AsyncPointer 0)

(defconst X-SyncPointer 1)

(defconst X-ReplayPointer 2)

(defconst X-AsyncKeyboard 3)

(defconst X-SyncKeyboard 4)

(defconst X-ReplayKeyboard 5)

(defconst X-AsyncBoth 6)

(defconst X-SyncBoth 7)

(defconst X-CWBackPixmap 1)

(defconst X-CWBackPixel 2)

(defconst X-CWBorderPixmap 4)

(defconst X-CWBorderPixel 8)

(defconst X-CWBitGravity 16)

(defconst X-CWWinGravity 32)

(defconst X-CWBackingStore 64)

(defconst X-CWBackingPlanes 128)

(defconst X-CWBackingPixel 256)

(defconst X-CWOverrideRedirect 512)

(defconst X-CWSaveUnder 1024)

(defconst X-CWEventMask 2048)

(defconst X-CWDontPropagate 4096)

(defconst X-CWColormap 8192)

(defconst X-CWCursor 16384)

(defconst X-SetModeInsert 0)

(defconst X-SetModeDelete 1)

(defconst X-CWX 1)

(defconst X-CWY 2)

(defconst X-CWWidth 4)

(defconst X-CWHeight 8)

(defconst X-CWBorderWidth 16)

(defconst X-CWSibling 32)

(defconst X-CWStackMode 64)

(defconst X-XC-num_glyphs 154)

(defconst X-XC-X_cursor 0)

(defconst X-XC-arrow 2)

(defconst X-XC-based_arrow_down 4)

(defconst X-XC-based_arrow_up 6)

(defconst X-XC-boat 8)

(defconst X-XC-bogosity 10)

(defconst X-XC-bottom_left_corner 12)

(defconst X-XC-bottom_right_corner 14)

(defconst X-XC-bottom_side 16)

(defconst X-XC-bottom_tee 18)

(defconst X-XC-box_spiral 20)

(defconst X-XC-center_ptr 22)

(defconst X-XC-circle 24)

(defconst X-XC-clock 26)

(defconst X-XC-coffee_mug 28)

(defconst X-XC-cross 30)

(defconst X-XC-cross_reverse 32)

(defconst X-XC-crosshair 34)

(defconst X-XC-diamond_cross 36)

(defconst X-XC-dot 38)

(defconst X-XC-dotbox 40)

(defconst X-XC-double_arrow 42)

(defconst X-XC-draft_large 44)

(defconst X-XC-draft_small 46)

(defconst X-XC-draped_box 48)

(defconst X-XC-exchange 50)

(defconst X-XC-fleur 52)

(defconst X-XC-gobbler 54)

(defconst X-XC-gumby 56)

(defconst X-XC-hand1 58)

(defconst X-XC-hand2 60)

(defconst X-XC-heart 62)

(defconst X-XC-icon 64)

(defconst X-XC-iron_cross 66)

(defconst X-XC-left_ptr 68)

(defconst X-XC-left_side 70)

(defconst X-XC-left_tee 72)

(defconst X-XC-leftbutton 74)

(defconst X-XC-ll_angle 76)

(defconst X-XC-lr_angle 78)

(defconst X-XC-man 80)

(defconst X-XC-middlebutton 82)

(defconst X-XC-mouse 84)

(defconst X-XC-pencil 86)

(defconst X-XC-pirate 88)

(defconst X-XC-plus 90)

(defconst X-XC-question_arrow 92)

(defconst X-XC-right_ptr 94)

(defconst X-XC-right_side 96)

(defconst X-XC-right_tee 98)

(defconst X-XC-rightbutton 100)

(defconst X-XC-rtl_logo 102)

(defconst X-XC-sailboat 104)

(defconst X-XC-sb_down_arrow 106)

(defconst X-XC-sb_h_double_arrow 108)

(defconst X-XC-sb_left_arrow 110)

(defconst X-XC-sb_right_arrow 112)

(defconst X-XC-sb_up_arrow 114)

(defconst X-XC-sb_v_double_arrow 116)

(defconst X-XC-shuttle 118)

(defconst X-XC-sizing 120)

(defconst X-XC-spider 122)

(defconst X-XC-spraycan 124)

(defconst X-XC-star 126)

(defconst X-XC-target 128)

(defconst X-XC-tcross 130)

(defconst X-XC-top_left_arrow 132)

(defconst X-XC-top_left_corner 134)

(defconst X-XC-top_right_corner 136)

(defconst X-XC-top_side 138)

(defconst X-XC-top_tee 140)

(defconst X-XC-trek 142)

(defconst X-XC-ul_angle 144)

(defconst X-XC-umbrella 146)

(defconst X-XC-ur_angle 148)

(defconst X-XC-watch 150)

(defconst X-XC-xterm 152)

(defconst XK-Shift-L 65505)

(defconst XK-Shift-R 65506)

(defconst XK-Control-L 65507)

(defconst XK-Control-R 65508)

(defconst XK-Caps-Lock 65509)

(defconst XK-Shift-Lock 65510)

(defconst XK-Meta-L 65511)

(defconst XK-Meta-R 65512)

(defconst XK-Alt-L 65513)

(defconst XK-Alt-R 65514)

(defconst XK-Super-L 65515)

(defconst XK-Super-R 65516)

(defconst XK-Hyper-L 65517)

(defconst XK-Hyper-R 65518)

(defconst XK-BackSpace 65288)

(defconst XK-Tab 65289)

(defconst XK-Linefeed 65290)

(defconst XK-Clear 65291)

(defconst XK-Return 65293)

(defconst XK-Pause 65299)

(defconst XK-Scroll-Lock 65300)

(defconst XK-Sys-Req 65301)

(defconst XK-Escape 65307)

(defconst XK-Delete 65535)

(defconst XK-Select 65376 "\
Select, mark")

(defconst XK-Print 65377)

(defconst XK-Execute 65378 "\
Execute, run, do")

(defconst XK-Insert 65379 "\
Insert, insert here")

(defconst XK-Undo 65381 "\
Undo, oops")

(defconst XK-Redo 65382 "\
redo, again")

(defconst XK-Menu 65383)

(defconst XK-Find 65384 "\
Find, search")

(defconst XK-Cancel 65385 "\
Cancel, stop, abort, exit")

(defconst XK-Help 65386 "\
Help")

(defconst XK-Break 65387)

(defconst XK-ModeSwitch 65406 "\
Character set switch")

(defconst XK-ScriptSwitch 65406 "\
Alias for mode_switch")

(defconst XK-NumLock 65407)

(defconst XK-F1 65470)

(defconst XK-F2 65471)

(defconst XK-F3 65472)

(defconst XK-F4 65473)

(defconst XK-F5 65474)

(defconst XK-F6 65475)

(defconst XK-F7 65476)

(defconst XK-F8 65477)

(defconst XK-F9 65478)

(defconst XK-F10 65479)

(defconst XK-F11 65480)

(defconst XK-L1 65480)

(defconst XK-F12 65481)

(defconst XK-L2 65481)

(defconst XK-F13 65482)

(defconst XK-L3 65482)

(defconst XK-F14 65483)

(defconst XK-L4 65483)

(defconst XK-F15 65484)

(defconst XK-L5 65484)

(defconst XK-F16 65485)

(defconst XK-L6 65485)

(defconst XK-F17 65486)

(defconst XK-L7 65486)

(defconst XK-F18 65487)

(defconst XK-L8 65487)

(defconst XK-F19 65488)

(defconst XK-L9 65488)

(defconst XK-F20 65489)

(defconst XK-L10 65489)

(defconst XK-F21 65490)

(defconst XK-R1 65490)

(defconst XK-F22 65491)

(defconst XK-R2 65491)

(defconst XK-F23 65492)

(defconst XK-R3 65492)

(defconst XK-F24 65493)

(defconst XK-R4 65493)

(defconst XK-F25 65494)

(defconst XK-R5 65494)

(defconst XK-F26 65495)

(defconst XK-R6 65495)

(defconst XK-F27 65496)

(defconst XK-R7 65496)

(defconst XK-F28 65497)

(defconst XK-R8 65497)

(defconst XK-F29 65498)

(defconst XK-R9 65498)

(defconst XK-F30 65499)

(defconst XK-R10 65499)

(defconst XK-F31 65500)

(defconst XK-R11 65500)

(defconst XK-F32 65501)

(defconst XK-R12 65501)

(defconst XK-F33 65502)

(defconst XK-R13 65502)

(defconst XK-F34 65503)

(defconst XK-R14 65503)

(defconst XK-F35 65504)

(defconst XK-R15 65504)

(defconst XK-Space 32)

(defconst XK-Home 65360)

(defconst XK-Left 65361)

(defconst XK-Up 65362)

(defconst XK-Right 65363)

(defconst XK-Down 65364)

(defconst XK-Prior 65365)

(defconst XK-PageUp 65365)

(defconst XK-Next 65366)

(defconst XK-PageDown 65366)

(defconst XK-End 65367)

(defconst XK-Begin 65368)

(defconst X-WithdrawnState 0.0)

(defconst X-NormalState 1.0)

(defconst X-IconicState 3.0)

(defconst X-NotifyNormal 0)

(defconst X-NotifyGrab 1)

(defconst X-NotifyUngrab 2)

(defconst X-NotifyWhileGrabbed 3)

(defconst X-NotifyHint 1)

(defconst X-NotifyAncestor 0)

(defconst X-NotifyVirtual 1)

(defconst X-NotifyInferior 2)

(defconst X-NotifyNonlinear 3)

(defconst X-NotifyNonlinearVirtual 4)

(defconst X-NotifyPointer 5)

(defconst X-NotifyPointerRoot 6)

(defconst X-NotifyDetailNone 7)

(defconst X-Unmapped 0)

(defconst X-Unviewable 1)

(defconst X-Viewable 2)

(defconst X-LSBFirst 0)

(defconst X-MSBFirst 1)

;;;***

;;;### (autoloads (XImagePut XDestroyImage XCreateImage) "xlib-img" "lisp/xlib-img.el")

(defstruct (X-Image (:predicate X-Image-isimage-p)) width height xoffset format data byte-order bitmap-scanline-unit bitmap-bit-order bitmap-scanline-pad depth bytes-per-line bits-per-pixel (red-mask 0) (green-mask 0) (blue-mask 0) create-image get-pixel put-pixel add-pixel destroy-image)

(autoload 'XCreateImage "xlib-img" "\
Create new image." nil nil)

(autoload 'XDestroyImage "xlib-img" "\
Destroy image IMG." nil nil)

(autoload 'XImagePut "xlib-img" "\
On display XDPY and drawable D at X Y put an XIMG." nil nil)

;;;***

;;;### (autoloads (Xmask-hex-string Xmask-string Xtest Xmask-or Xmask-and Xmask X-pad int->string3 string4->number string2->number string4->int int->string4 string->int int->string Xforcenum XCharacter Xtruncate) "xlib-math" "lisp/xlib-math.el")

(autoload 'Xtruncate "xlib-math" "\
Do a safe truncate of VAL that might be larger than MAXINT." nil 'macro)

(autoload 'XCharacter "xlib-math" "\
Convert VAL (a float) into a truncated character value." nil 'macro)

(autoload 'Xforcenum "xlib-math" "\
Force VAL (a character) to be a number.
This macro forces XEmacs 20.3 to behave." nil 'macro)

(autoload 'int->string "xlib-math" "\
Convert NUM into a 2 byte string in network order and return." nil nil)

(defalias 'int->string2 'int->string)

(autoload 'string->int "xlib-math" "\
Convert STRING 1st two characters into an integer and return." nil nil)

(autoload 'int->string4 "xlib-math" "\
Convert NUM (a float or int) into a 4 byte network order string." nil nil)

(autoload 'string4->int "xlib-math" "\
Convert STRING 1st four characters into a float and return." nil nil)

(autoload 'string2->number "xlib-math" "\
Convert 2 first bytes in STRING to number." nil nil)

(autoload 'string4->number "xlib-math" "\
Convert 4 first bytes in STRING to number.
NOTE: Use `string4->int' when overflow may occur." nil nil)

(autoload 'int->string3 "xlib-math" "\
Convert 3 first bytes in STRING to integer." nil nil)

(autoload 'X-pad "xlib-math" "\
Return a number which is the padding for an X message of length NUMBER." nil nil)

(autoload 'Xmask "xlib-math" "\
Create a mask with a bit set in position POS.
This routine will not work for position 32 and up because we sim
4 bytes of info" nil nil)

(autoload 'Xmask-and "xlib-math" "\
Logically `and' VAL and MASK together.
They are floats to be broken down into two two byte ints.
MASK is stored in ARGS which is a list of *fill in when I remember*" nil nil)

(autoload 'Xmask-or "xlib-math" "\
Logically or VAL and MASK together.
They are floats to be broken down into two two byte ints.
MASK is stored in ARGS which is a list of *fill in when I remember*" nil nil)

(autoload 'Xtest "xlib-math" "\
Test value of bytes VAL for presence of FLAG.
Return t if it exists, nil otherwise." nil nil)

(autoload 'Xmask-string "xlib-math" "\
Convert MASK into a string of 0s and 1s." nil nil)

(autoload 'Xmask-hex-string "xlib-math" "\
Convert MASK into a hexidecimal string." nil nil)

;;;***

;;;### (autoloads (XTrayInit) "xlib-tray" "lisp/xlib-tray.el")

(autoload 'XTrayInit "xlib-tray" "\
Initialize atoms for interaction with system tray." nil nil)

;;;***

;;;### (autoloads (X-Create-message X-Dpy-send-read X-Dpy-send X-Dpy-send-flush X-Dpy-log X-Dpy-close X-Dpy-create-connection X-Dpy-get-id X-Dpy-p X-formatpad X-formatint X-formatfind X-Dpy-rem-property X-Dpy-get-property X-Dpy-put-property X-Dpy-reqseq) "xlib-xc" "lisp/xlib-xc.el")

(defstruct X-Visual id class bits-per-rgb cmap-entries red-mask green-mask blue-mask)

(defstruct X-Depth depth visuals)

(defstruct X-Screen dpy root colormap white-pixel black-pixel root-event-mask visualid backingstores save-unders width height mwidth mheight min-maps max-maps default-gc root-depth depths)

(defstruct X-ScreenFormat depth bits-per-pixel scanline-pad)

(defstruct (X-Dpy (:predicate X-Dpy-isxdpy-p)) proc log-buffer properties (readings 0) (evq nil) (evq-protects 0) (snd-buf "") (snd-protects 0) (parse-guess-dispatcher 'X-Dpy-parse-message-guess) (events-dispatcher 'X-Dpy-default-events-dispatcher) event-handlers message-buffer name proto-maj proto-min vendor min-keycode max-keycode resource-base resource-mask (resource-id 1) (rseq-id 0) max-request-size motion-bufsize byte-order bitmap-scanline-unit bitmap-scanline-pad bitmap-bit-order formats (default-screen 0) screens error-hooks atoms windows fonts extensions)

(autoload 'X-Dpy-reqseq "xlib-xc" "\
Extract least significant 16bit from request sequenc id in XDPY." nil 'macro)

(autoload 'X-Dpy-put-property "xlib-xc" "\
Put property PROP with value VAL in XDPY's properties list." nil 'macro)

(autoload 'X-Dpy-get-property "xlib-xc" "\
Get property PROP from XDPY's properties list." nil 'macro)

(autoload 'X-Dpy-rem-property "xlib-xc" "\
Remove property PROP from XDPY's properties list." nil 'macro)

(autoload 'X-formatfind "xlib-xc" "\
On display XDPY find proper X-ScreenFormat for gived DEPTH." nil nil)

(autoload 'X-formatint "xlib-xc" "\
On display XDPY convert NUM to string." nil nil)

(autoload 'X-formatpad "xlib-xc" "\
Return padded STR." nil nil)

(autoload 'X-Dpy-p "xlib-xc" "\
Return non-nil if XDPY is X display.
If SIG is given and XDPY is not X display, SIG will be signaled." nil nil)

(autoload 'X-Dpy-get-id "xlib-xc" "\
Get id to be used on X display XDPY." nil nil)

(autoload 'X-Dpy-create-connection "xlib-xc" "\
Create X connection to display with name DNAME and number DNUM." nil nil)

(autoload 'X-Dpy-close "xlib-xc" "\
Close connection associated with XDPY." nil nil)

(autoload 'X-Dpy-log "xlib-xc" "\
Put a message in the in the log buffer specified by XDPY.
If XDPY is nil, then put into current buffer.  Log additional ARGS as well." nil nil)

(autoload 'X-Dpy-send-flush "xlib-xc" "\
Just send S to display XDPY. Do not increase rseq-id." nil nil)

(autoload 'X-Dpy-send "xlib-xc" "\
Send the X server DPY the string S. Increase request id rseq-id.
There is special mode when we are collecting X output to send it all at once." nil nil)

(autoload 'X-Dpy-send-read "xlib-xc" "\
Send S to display XDPY and receive answer according to receive fields RF." nil nil)

(defconst X-client-to-open (list [1 X-byte-order] [1 0] [2 X-protocol-major-version] [2 X-protocol-minor-version] [2 0] [2 0] [2 0]) "\
XStruct list of sizes when opening a connection.")

(autoload 'X-Create-message "xlib-xc" "\
Takes the MESSAGE-S structure and builds a net string.
MESSAGE-S is a list of vectors and symbols which formulate the message
to be sent to the XServer.  Each vector is of this form:
  [ SIZE VALUE ]
  SIZE is the number of BYTES used by the message.
  VALUE is the lisp object whose value is to take up SIZE bytes.
  If VALUE or SIZE is a symbol or list, extract that elements value.
    If the resulting value is still a list or symbol, extract it's value
    until it is no longer a symbol or a list.
  If VALUE is a number, massage it to the correct size.
  If VALUE is a string, append that string verbatum.
  If VALUE is nil, fill it with that many NULL characters.

When PAD-NOTNEED is non-nil, then do not pad to 4 bytes." nil nil)

;;;***

;;;### (autoloads (XSetFont XSync XSyncEvents XPeekIfEvent XCheckIfEvent XCheckIfEvent-in-queue XIfEvent XNextEvent XForceScreenSaver XGetScreenSaver XSetScreenSaver X-Dpy-get-extension XQueryExtension XChangeActivePointerGrab XCreateGlyphCursor XFreePixmap XCreatePixmap XQueryTextExtents XQueryFont XOpenFont XGetModifierMapping XGetKeyboardMapping XQueryKeymap XSendEvent XChangeSaveSet XTranslateCoordinates XGetGeometry XReparentWindow XSetInputFocus XGetInputFocus XAllowEvents XUngrabKey XGrabKey XUngrabButton XGrabButton XUngrabPointer XGrabPointer XUngrabKeyboard XGrabKeyboard XQueryPointer XUngrabServer XGrabServer XWarpPointer XConvertSelection XGetSelectionOwner XSetSelectionOwner XGetImage XPutImage XDrawText16 XDrawText8 XImageString XDrawString XFillArcs XFillArc XDrawArc XDrawArcs XFillRectangles XFillRectangle XDrawRectangle XDrawRectangles XDrawSegments XDrawLine XFillPoly XDrawLines XDrawPoint XDrawPoints XCopyPlane XCopyArea XClearArea XFreeGC XSetClipRectangles XSetDashes XChangeGC XCreateGC XQueryColors XFreeColors XStoreColor XStoreColors XAllocColorCells XAllocNamedColor XAllocColor XFreeColormap XCreateColormap XWMProtocol-set-p XGetWMProtocols XGetWMState XGetWMTransientFor XGetWMClientLeader XGetWMClass XGetWMCommand XGetWMNormalHints XGetWMHints XGetWMName XGetWindowProperty XSetWMCommand XSetWMState XSetWMNormalHints XSetWMName XSetWMClass XSetWMProtocols XChangeProperty XGetAtomName XInternAtom XQueryTree XDestroySubwindows XDestroyWindow XUnmapWindow XMapWindow XSetWindowBorderWidth XMoveResizeWindow XResizeWindow XMoveWindow XRaiseWindow XLowerWindow XConfigureWindow XGetWindowAttributes XSetWindowColormap XSetWindowBorder XSetWindowBackground XSelectInput XChangeWindowAttributes XCreateWindow XBell XScreenCheck XCloseDisplay XOpenDisplay X-invalidate-cl-struct) "xlib-xlib" "lisp/xlib-xlib.el")

(autoload 'X-invalidate-cl-struct "xlib-xlib" "\
Invalidate CL-X, after `X-invalidate-cl-struct' it won't be cl struct anymore.
NOTE: works only if CL-X is vector." nil nil)

(autoload 'XOpenDisplay "xlib-xlib" "\
Open an X connection to the display named NAME such as host:0.1.
Optionally you may pass DISPNUM - display number and SCREEN - screen number." nil nil)

(autoload 'XCloseDisplay "xlib-xlib" "\
Close the connection to display XDPY." nil nil)

(autoload 'XScreenCheck "xlib-xlib" "\
Check SCRNUM screen on display XDPY." nil nil)

(autoload 'XBell "xlib-xlib" "\
Ring the bell on XDPY at PERCENT volume." nil nil)

(autoload 'XCreateWindow "xlib-xlib" "\
Create a window." nil nil)

(autoload 'XChangeWindowAttributes "xlib-xlib" "\
On XDPY and window WIN, change to the ATTRIBUTES." nil nil)

(autoload 'XSelectInput "xlib-xlib" "\
On display XDPY for window WIN, set the EVENT mask." nil nil)

(autoload 'XSetWindowBackground "xlib-xlib" "\
On display XDPY for window WIN, set the background to PIXEL." nil nil)

(autoload 'XSetWindowBorder "xlib-xlib" "\
On display XDPY for window WIN, set the border color to PIXEL." nil nil)

(autoload 'XSetWindowColormap "xlib-xlib" "\
On display XDPY for window WIN, set the colormap to CMAP-ID." nil nil)

(autoload 'XGetWindowAttributes "xlib-xlib" "\
On display XDPY, get window's WIN attributes as an `X-Attr'." nil nil)

(autoload 'XConfigureWindow "xlib-xlib" "\
On display XDPY, change window WIN to have configuration CONF.
CONF is an `X-Conf' structure." nil nil)

(autoload 'XLowerWindow "xlib-xlib" "\
On display XDPY, lower window WIN." nil nil)

(autoload 'XRaiseWindow "xlib-xlib" "\
On display XDPY, raise window WIN." nil nil)

(autoload 'XMoveWindow "xlib-xlib" "\
On display XDPY, move window WIN to position X Y." nil nil)

(autoload 'XResizeWindow "xlib-xlib" "\
On display XDPY, resize window WIN to dimentions W H." nil nil)

(autoload 'XMoveResizeWindow "xlib-xlib" "\
On display XDPY, move and resize window WIN to X, Y, W, H." nil nil)

(autoload 'XSetWindowBorderWidth "xlib-xlib" "\
On display XDPY, set window's WIN border to be WIDTH pixels wide." nil nil)

(autoload 'XMapWindow "xlib-xlib" "\
On display XDPY, map WIN to the screen (to make it visible.)." nil nil)

(autoload 'XUnmapWindow "xlib-xlib" "\
On display XDPY, unmap window WIN to make it hidden." nil nil)

(autoload 'XDestroyWindow "xlib-xlib" "\
On display XDPY, destroy window WIN." nil nil)

(autoload 'XDestroySubwindows "xlib-xlib" "\
On display XDPY, destroy subwindows of window WIN." nil nil)

(autoload 'XQueryTree "xlib-xlib" "\
Query display XDPY for all children of window WIN.
Returns a list of the form (ROOT PARENT CHILD1 CHILD2 ...)
on success, or nil on failure.  ROOT is the root window for the display that
WINDOW is on.  PARENT is the parent of WINDOW, and CHILDN are the
children of WINDOW." nil nil)

(autoload 'XInternAtom "xlib-xlib" "\
On display XDPY, return the Atom with NAME.
If ONLY-IF-EXISTS is nil, then the atom is created if it does not already
exist.  The Atom object is returned." nil nil)

(autoload 'XGetAtomName "xlib-xlib" "\
On display XDPY, get the textual name of ATOM.
*UNTESTED*" nil nil)

(autoload 'XChangeProperty "xlib-xlib" "\
On display XDPY for window WIN, change PROPERTY.
PROPERTY is changed based on a TYPE, FORMAT, and MODE with DATA.
There are NElements." nil nil)

(autoload 'XSetWMProtocols "xlib-xlib" "\
On display XDPY, set window's WIN protocols to PROTOCOL_ATOMS.
Convenience routine which calls `XChangeProperty'" nil nil)

(autoload 'XSetWMClass "xlib-xlib" "\
On displayX DPY, set window's WIN Class to WM-CLASS.
WM-CLASS should be in form '(class-name class-intance)." nil nil)

(autoload 'XSetWMName "xlib-xlib" nil nil nil)

(autoload 'XSetWMNormalHints "xlib-xlib" "\
On display XDPY, set window's WIN normal hints to HINTS.
HINTS is list in format (x1 x2 ... x18)." nil nil)

(autoload 'XSetWMState "xlib-xlib" "\
On display XDPY, set window's WIN state to WM-STATE.
WM-STATE is one of `X-WithdrawnState', `X-NormalState' or `X-IconicState'." nil nil)

(autoload 'XSetWMCommand "xlib-xlib" "\
On display XDPY set window's WIN WM_COMMAND property to CMD." nil nil)

(autoload 'XGetWindowProperty "xlib-xlib" "\
On display XDPY, get window's WIN PROPERTY atom value.
Get the data from optional OFFSET, and a maximum of LENGTH bytes.
OFFSET and LENGTH refer to 32 bit chunks, not 8 bit chunks.
Third optional argument DELETE will delete the property if Non-nil.
Fourth argument REQUIRED-TYPE filters only properties of the desired type.
If REQUIRED-TYPE is `XA-AnyPropertyType', or nil then no filtering is done.
The returned list is of the form:
  (TYPE_RETURN BYTES_AFTER PROP1 PROP2 ...)
Where TYPE_RETURN is the type (of same for as REQUIRED-TYPE) is the actual
type of the data being returned.
FORMAT_RETURN is the format of the data (such as 8, 16, or 32).
BYTES_AFTER is the number of bytes still attached to the property.
If there are extra bytes, then a second call to `XGetWindowProperty' will
be needed.  Lastly, PROP1 through PROPN is the list of properties
originally requested.
  It is common to call `XGetWindowProperty' asking for no data so that
BYTES_AFTER contains the exact amount of data we want to request." nil nil)

(autoload 'XGetWMName "xlib-xlib" "\
On display XDPY, get window's WIN name." nil nil)

(autoload 'XGetWMHints "xlib-xlib" "\
On display XDPY, get window's WIN WM_HINTS." nil nil)

(autoload 'XGetWMNormalHints "xlib-xlib" "\
On display XDPY, get normal hints for WIN." nil nil)

(autoload 'XGetWMCommand "xlib-xlib" "\
On display XDPY, get window's WIN WM_COMMAND." nil nil)

(autoload 'XGetWMClass "xlib-xlib" "\
On display XDPY, get window's WIN WM_CLASS." nil nil)

(autoload 'XGetWMClientLeader "xlib-xlib" "\
Get window property for WM_CLIENT_LEADER atom." nil nil)

(autoload 'XGetWMTransientFor "xlib-xlib" "\
Get WM_TRANSIENT_FOR property.
Returns list in form `(seq val window-for-wich-win-is-trasient)'." nil nil)

(autoload 'XGetWMState "xlib-xlib" "\
On display XDPY get WM_STATE property for WIN." nil nil)

(autoload 'XGetWMProtocols "xlib-xlib" "\
On display XDPY get WM_PROTOCOLS property for WIN." nil nil)

(autoload 'XWMProtocol-set-p "xlib-xlib" "\
Return non-nil when atom with NAME is in WM_PROTOCOLS WMPROTO." nil nil)

(autoload 'XCreateColormap "xlib-xlib" "\
Create a colormap. Default values are:

VISUAL    - CopyFromParent
ALLOCATE  - All are writable (1) (0 -> none writable)

args (XDPY WIN &optional VISUAL ALLOCTE)" nil nil)

(autoload 'XFreeColormap "xlib-xlib" "\
Frees a colormap CMAP.
args (XDPY CMAP)" nil nil)

(autoload 'XAllocColor "xlib-xlib" "\
On display XDPY allocate in CMAP the color struct COLOR.
Use `X-Color' to create.
Returns non-nil if successful." nil nil)

(autoload 'XAllocNamedColor "xlib-xlib" "\
Allocate a color based on the color struct COLOR-VISUAL and COLOR-EXACT.
If COLOR-EXACT is nil or absent, ignore.
args (DISPLAY CMAP NAME COLOR-VISUAL &optional COLOR-EXACT)" nil nil)

(autoload 'XAllocColorCells "xlib-xlib" "\
On display XDPY allocate NCOLORS in colormap CMAP." nil nil)

(autoload 'XStoreColors "xlib-xlib" "\
On display XDPY in CMAP, store COLORS. (A list of 'X-Color)
These colors are X-Color lists containing the PIXEL, RGB values and
FLAGs (which indicates what part of the RGB value is stored into
PIXEL's slot." nil nil)

(autoload 'XStoreColor "xlib-xlib" "\
On display XDPY in CMAP, store COLORS.
These colors are X-Color lists containing the PIXEL, RGB values and
FLAGs (which indicates what part of the RGB value is stored into
PIXEL's slot.
  Optionally, COLOR can be a float, and it's new value indicated by
the values of RGB, or X-Color and it will be stored as is." nil nil)

(autoload 'XFreeColors "xlib-xlib" "\
On display XDPY in CMAP, free COLORS from the server.
The colors are deallocated on PLANES, which is a mask.  Use 0 for
PLANES if you don't know what it's for." nil nil)

(autoload 'XQueryColors "xlib-xlib" "\
On display XDPY and colormap CMAP query COLOR-IDS." nil nil)

(autoload 'XCreateGC "xlib-xlib" "\
Allocate a graphic context display XDPY on the drawable D.
Base this new context on GC." nil nil)

(autoload 'XChangeGC "xlib-xlib" "\
On display XDPY change GC to have new VALUES.
I.e. update GC's info on server." nil nil)

(autoload 'XSetDashes "xlib-xlib" "\
On display XDPY for GC set DASH-OFFSET and DASHES for dashed line styles." nil nil)

(autoload 'XSetClipRectangles "xlib-xlib" "\
On display XDPY for GC change clip-mask according to CLIP-X-ORIGIN,
CLIP-Y-ORIGIN and RECTANGLES.

You may specify ORDER to speed up X server, ORDER is one of
`X-UnSorted', `X-YSorted', `X-YXSorted' or `X-YXBanded'." nil nil)

(autoload 'XFreeGC "xlib-xlib" "\
Allocate a graphic context display XDPY on the drawable D.
Base this new context on GC." nil nil)

(autoload 'XClearArea "xlib-xlib" "\
On display XDPY in WIN clear rectangle X Y WIDTH HEIGHT." nil nil)

(autoload 'XCopyArea "xlib-xlib" "\
On display XDPY combine specified rectangle of SCR-D with DST-D." nil nil)

(autoload 'XCopyPlane "xlib-xlib" "\
On display XDPY ..." nil nil)

(autoload 'XDrawPoints "xlib-xlib" "\
Draw points on a drawable. (XDPY D GC PTS &optional MODE)." nil nil)

(autoload 'XDrawPoint "xlib-xlib" "\
Draw a point. (XDPY D GC X Y)." nil nil)

(autoload 'XDrawLines "xlib-xlib" "\
Draw a multipoint line. (XDPY D GC PTS &optional MODE)." nil nil)

(autoload 'XFillPoly "xlib-xlib" "\
Fill poly." nil nil)

(autoload 'XDrawLine "xlib-xlib" "\
Draw a line on display XDPY in drawable D.
args (XDPY D GC X Y X2 Y2)." nil nil)

(autoload 'XDrawSegments "xlib-xlib" "\
Draw Segments. (XDPY D GC PTS &optional MODE).
Drawing segments is different from lines in that segments are disconnected
every other pair of points." nil nil)

(autoload 'XDrawRectangles "xlib-xlib" "\
Draw rectangles. (XDPY D GC RECTANGLES &optional FILL)." nil nil)

(autoload 'XDrawRectangle "xlib-xlib" "\
Draw a rectangle. (XDPY D GC X Y WIDTH HEIGHT)." nil nil)

(autoload 'XFillRectangle "xlib-xlib" "\
Draw a rectangle. (XDPY D GC X Y WIDTH HEIGHT)." nil nil)

(autoload 'XFillRectangles "xlib-xlib" "\
Draw rectangles. (XDPY D GC RECTANGLES)." nil nil)

(autoload 'XDrawArcs "xlib-xlib" "\
Draw arcs. (XDPY D GC ARCS &optional FILL)." nil nil)

(autoload 'XDrawArc "xlib-xlib" "\
Draw an arc on display XDPY in drawable D.
args (DISPLAY D GC X Y WIDTH HEIGHT ANGLE1 ANGLE2)" nil nil)

(autoload 'XFillArc "xlib-xlib" "\
Draw a filled arc on display XDPY in drawable D.
args (DISPLAY D GC X Y WIDTH HEIGHT ANGLE1 ANGLE2)" nil nil)

(autoload 'XFillArcs "xlib-xlib" "\
Draw filled arcs. (XDPY D GC ARCS)." nil nil)

(autoload 'XDrawString "xlib-xlib" "\
Draw a string at specified point. (XDPY D GC X Y STR &optional LEN)." nil nil)

(autoload 'XImageString "xlib-xlib" "\
Draw a string using ImageText8 request.
XDPY, D, GC, X, Y, STR and LEN are the same as in `XDrawString'." nil nil)

(autoload 'XDrawText8 "xlib-xlib" nil nil nil)

(autoload 'XDrawText16 "xlib-xlib" nil nil nil)

(autoload 'XPutImage "xlib-xlib" "\
On display XDPY and drawable D, put an image." nil nil)

(autoload 'XGetImage "xlib-xlib" "\
On display XDPY and drawable D, get image with geometry WIDTHxHEIGHT+X+Y in FORMAT.
PLANE-MASK is one of `X-AllPlanes' or something elese." nil nil)

(autoload 'XSetSelectionOwner "xlib-xlib" "\
Set SELECTION-ATOM to be owned by OWNER-WIN." nil nil)

(autoload 'XGetSelectionOwner "xlib-xlib" "\
Get owner of SELECTION-ATOM on display XDPY.
Returns nil or X-Win structure." nil nil)

(autoload 'XConvertSelection "xlib-xlib" "\
ConvertSelection." nil nil)

(autoload 'XWarpPointer "xlib-xlib" "\
On display XDPY warp pointer to DEST-X DEST-Y" nil nil)

(autoload 'XGrabServer "xlib-xlib" "\
Grabs X server on display XDPY" nil nil)

(autoload 'XUngrabServer "xlib-xlib" "\
Ungrab X server on display XDPY." nil nil)

(autoload 'XQueryPointer "xlib-xlib" "\
In display XDPY and window XWIN query pointer position." nil nil)

(autoload 'XGrabKeyboard "xlib-xlib" "\
On display XDPY in window GRAB-WIN start grabbing keyboard.
OWE - owner events (default `nil')
PMODE - Pointer grabbing mode (default `X-GrabModeAsync')
KMODE - Keyboard grabbing mode (default `X-GrabModeAsync')
TIME - Time when start to grab (default `X-CurrentTime')" nil nil)

(autoload 'XUngrabKeyboard "xlib-xlib" "\
On display XDPY at TIME stop grabbing keyboard.
Default TIME is `X-CurrentTime'." nil nil)

(autoload 'XGrabPointer "xlib-xlib" "\
On display XDPY in window GRAB-WIN start grabbing pointer.
CURSOR - Cursor to use while grabbing.
EV-MASK - Mask for events to receive. Result of `Xmask-or'.
OWE - owner events (default `nil')
PMODE - Pointer grabbing mode (default `X-GrabModeAsync')
KMODE - Keyboard grabbing mode (default `X-GrabModeAsync')
CONFTO-WIN - Confine to window (default `nil'
TIME - Time when start to grab (default `X-CurrentTime')" nil nil)

(autoload 'XUngrabPointer "xlib-xlib" "\
On display XDPY at TIME, stop grabbing pointer." nil nil)

(autoload 'XGrabButton "xlib-xlib" "\
On display XDPY in window GRAB-WIN, start grabbing for BUTTON with MODS.
TODO: Describe optional arguments." nil nil)

(autoload 'XUngrabButton "xlib-xlib" "\
On display XDPY in window GRAB-WIN stop grabbing for BUTTON with MODS." nil nil)

(autoload 'XGrabKey "xlib-xlib" "\
On display XDPY in window GRAB-WIN start grabbing for KEYCODE with MODS.
TODO: Description for OWE, PMODE and KMODE." nil nil)

(autoload 'XUngrabKey "xlib-xlib" "\
On display XDPY in window GRAB-WIN stop grabbing KEYCODE with MODS." nil nil)

(autoload 'XAllowEvents "xlib-xlib" "\
On display XDPY allow events in MODE." nil nil)

(autoload 'XGetInputFocus "xlib-xlib" "\
On display XDPY get curret input focus." nil nil)

(autoload 'XSetInputFocus "xlib-xlib" "\
On display XDPY set input focus to window WIN-OR-VAL.
REV-TO - Focus revert to when WIN-OR-VAL will lost input focus.
TIME - Set input focus at this time (default `X-CurrentTime')" nil nil)

(autoload 'XReparentWindow "xlib-xlib" "\
On display XDPY reparent window WIN to PARWIN at X Y." nil nil)

(autoload 'XGetGeometry "xlib-xlib" "\
On display XDPY get geomtry of WIN." nil nil)

(autoload 'XTranslateCoordinates "xlib-xlib" "\
On display XDPY translate SCR-X SCR-y coordinates to coordinates on DST-WIN." nil nil)

(autoload 'XChangeSaveSet "xlib-xlib" "\
On display XDPY change SaveSet according to CHANGE-MODE." nil nil)

(autoload 'XSendEvent "xlib-xlib" "\
WIN is X11 window or one of X-InputFocus, X-XXXxxxXXX.
Evil hack, do not use this function." nil nil)

(autoload 'XQueryKeymap "xlib-xlib" "\
On display XDPY query keyboard mapping." nil nil)

(autoload 'XGetKeyboardMapping "xlib-xlib" "\
On display XDPY get keyboard mapping." nil nil)

(autoload 'XGetModifierMapping "xlib-xlib" "\
On display XDPY get modifiers mapping." nil nil)

(autoload 'XOpenFont "xlib-xlib" "\
On display XDPY open FONT, created using `X-Font'." nil nil)

(autoload 'XQueryFont "xlib-xlib" "\
On display XDPY query for FONT." nil nil)

(autoload 'XQueryTextExtents "xlib-xlib" "\
On display XDPY fetch FONT's info for STRING." nil nil)

(autoload 'XCreatePixmap "xlib-xlib" "\
On display XDPY create PIXMAP using drawable D.
Return X-Pixmap structure." nil nil)

(autoload 'XFreePixmap "xlib-xlib" "\
On display XDPY free pixmap." nil nil)

(autoload 'XCreateGlyphCursor "xlib-xlib" "\
On display XDPY create CURSOR.
CURSOR is `X-Cursor' structure." nil nil)

(autoload 'XChangeActivePointerGrab "xlib-xlib" "\
Change active pointer grabbing." nil nil)

(autoload 'XQueryExtension "xlib-xlib" "\
On display XDPY query for extension with NAME." nil nil)

(autoload 'X-Dpy-get-extension "xlib-xlib" "\
On display XDPY get extension with EXTNAME.
If SIG, then signal an error if extension is not available." nil nil)

(autoload 'XSetScreenSaver "xlib-xlib" "\
On dispay XDPY set screen saver parameters." nil nil)

(autoload 'XGetScreenSaver "xlib-xlib" "\
On display XDPY get info about screen saver." nil nil)

(autoload 'XForceScreenSaver "xlib-xlib" "\
On display XDPY force screen saver in mode." nil nil)

(autoload 'XNextEvent "xlib-xlib" "\
On display XDPY get next X Event.
Optionally you can specify TIMEOUT.
IF TIMEOUT specified and no event arrived in TIMEOUT period, return nil." nil nil)

(autoload 'XIfEvent "xlib-xlib" "\
Block until predicate return non-nil.
If PEEK is non-nil then do not remove matched event from events queue.
Return XEV structure." nil nil)

(autoload 'XCheckIfEvent-in-queue "xlib-xlib" "\
Check is there event in QUEUE for which PREDIC return non-nil.
Return event. If PEEK is non-nil - do not remove event from QUEUE." nil nil)

(autoload 'XCheckIfEvent "xlib-xlib" "\
Same as `XIfEvent', but do not block and return `nil' if there no match.
If PEEK is non-nil do not remove matching event from queue." nil nil)

(autoload 'XPeekIfEvent "xlib-xlib" "\
Block until PREDIC return t.
Event does not removed from events queue." nil nil)

(autoload 'XSyncEvents "xlib-xlib" "\
Syncronize events ready for XDPY." nil nil)

(autoload 'XSync "xlib-xlib" "\
Sync with server.
When DISCARD is non nil, remove all events in events queue, even these
who was before entering `XSync'." nil nil)

(autoload 'XSetFont "xlib-xlib" "\
On display XDPY for GC set FONT." nil nil)

;;;***

;;;### (autoloads (X:xpm-pixmap-from-file X:xpm-pixmap-from-data X:xpm-make-pixmap-from-ximg X:xpm-img-from-file X:xpm-img-from-data) "xlib-xpm" "lisp/xlib-xpm.el")

(autoload 'X:xpm-img-from-data "xlib-xpm" nil nil nil)

(autoload 'X:xpm-img-from-file "xlib-xpm" nil nil nil)

(autoload 'X:xpm-make-pixmap-from-ximg "xlib-xpm" "\
On display XDPY and drawable D, create X-Pixmap using OBTAINER to get img data." nil nil)

(autoload 'X:xpm-pixmap-from-data "xlib-xpm" "\
On display XDPY and drawable D create X-Pixmap from DATA." nil nil)

(autoload 'X:xpm-pixmap-from-file "xlib-xpm" "\
On display XDPY and drawable D create X-Pixmap from FILE." nil nil)

;;;***

;;;### (autoloads (X-Dpy-parse-message X-Generic-enqueue X-Dpy-send-excursion X-Dpy-events-excursion X-Dpy-read-excursion X-EventHandler-runall X-EventHandler-disable X-EventHandler-enable X-EventHandler-rem X-EventHandler-isset X-EventHandler-add X-Event-CASE X-Event-name X-Event-win X-Event-p) "xlib-xr" "lisp/xlib-xr.el")

(defstruct (X-Event (:predicate X-Event-isevent-p)) dpy type send-event evdata evinfo list properties)

(autoload 'X-Event-p "xlib-xr" "\
Return non-nil if EV is X-Event." nil nil)

(autoload 'X-Event-win "xlib-xr" "\
Return window for which EV generated." nil nil)

(autoload 'X-Event-name "xlib-xr" "\
Return symbolic XEV name." nil nil)

(autoload 'X-Event-CASE "xlib-xr" "\
Run event case. BODY in form (EVTYPE FORMS) (EVTYPE FORMS) ..
EVTYPE is one of :X-KeyPress, :X-KeyRelease etc." nil 'macro)

(autoload 'X-EventHandler-add "xlib-xr" "\
To event handlers list EVHLIST add event HANDLER.

HANDLER is function which should accept three arguments - xdpy(X-Dpy),
xwin(X-Win) and xev(X-Event).  Only events with type that in
EVTYPES-LIST are passed to HANDLER. By default all events passed.
PRIORITY is place in events handler list, i.e. when HANDLER will be
called. Higher priorities runs first.

Return new list, use it like `(setq lst (X-EventHandler-add lst 'handler))'." nil nil)

(autoload 'X-EventHandler-isset "xlib-xr" "\
Examine EVHLIST and return X-EventHandler with HANDLER, PRIORITY and EVTYPES-LIST.
If you does not specify PRIORITY and EVTYPES-LIST, only matching with HANDLER occurs.
If event handler not found - nil will be returned." nil nil)

(autoload 'X-EventHandler-rem "xlib-xr" "\
From EVHLIST remove event HANDLER with PRIORITY and EVTYPES-LIST.
If you does not specify PRIORITY and EVTYPES-LIST, only matching with HANDLER occurs.
Return new list, use it like `(setq lst (X-EventHandler-rem lst 'handler))'." nil nil)

(autoload 'X-EventHandler-enable "xlib-xr" "\
In event handlers list EVHLIST mark HANDLER with PRIORITY and EVTYPES-LIST as active." nil nil)

(autoload 'X-EventHandler-disable "xlib-xr" "\
In event handlers list EVHLIST mark HANDLER with PRIORITY and EVTYPES-LIST as inactive." nil nil)

(autoload 'X-EventHandler-runall "xlib-xr" "\
Run all event handlers in EVHLIST on XEV.
Signal `X-Events-stop' to stop events processing." nil nil)
(autoload 'X-Event-xkey-keycode "xlib-xr")
(autoload 'X-Event-xkey-time "xlib-xr")
(autoload 'X-Event-xkey-root "xlib-xr")
(autoload 'X-Event-xkey-event "xlib-xr")
(autoload 'X-Event-xkey-child "xlib-xr")
(autoload 'X-Event-xkey-root-x "xlib-xr")
(autoload 'X-Event-xkey-root-y "xlib-xr")
(autoload 'X-Event-xkey-event-x "xlib-xr")
(autoload 'X-Event-xkey-event-y "xlib-xr")
(autoload 'X-Event-xkey-state "xlib-xr")
(autoload 'X-Event-xkey-same-screen "xlib-xr")
(autoload 'X-Event-xbutton-button "xlib-xr")
(autoload 'X-Event-xbutton-time "xlib-xr")
(autoload 'X-Event-xbutton-root "xlib-xr")
(autoload 'X-Event-xbutton-event "xlib-xr")
(autoload 'X-Event-xbutton-child "xlib-xr")
(autoload 'X-Event-xbutton-root-x "xlib-xr")
(autoload 'X-Event-xbutton-root-y "xlib-xr")
(autoload 'X-Event-xbutton-event-x "xlib-xr")
(autoload 'X-Event-xbutton-event-y "xlib-xr")
(autoload 'X-Event-xbutton-state "xlib-xr")
(autoload 'X-Event-xbutton-same-screen "xlib-xr")
(autoload 'X-Event-xmotion-time "xlib-xr")
(autoload 'X-Event-xmotion-root "xlib-xr")
(autoload 'X-Event-xmotion-event "xlib-xr")
(autoload 'X-Event-xmotion-child "xlib-xr")
(autoload 'X-Event-xmotion-root-x "xlib-xr")
(autoload 'X-Event-xmotion-root-y "xlib-xr")
(autoload 'X-Event-xmotion-event-x "xlib-xr")
(autoload 'X-Event-xmotion-event-y "xlib-xr")
(autoload 'X-Event-xmotion-state "xlib-xr")
(autoload 'X-Event-xmotion-same-screen "xlib-xr")
(autoload 'X-Event-xcrossing-time "xlib-xr")
(autoload 'X-Event-xcrossing-root "xlib-xr")
(autoload 'X-Event-xcrossing-event "xlib-xr")
(autoload 'X-Event-xcrossing-child "xlib-xr")
(autoload 'X-Event-xcrossing-root-x "xlib-xr")
(autoload 'X-Event-xcrossing-root-y "xlib-xr")
(autoload 'X-Event-xcrossing-event-x "xlib-xr")
(autoload 'X-Event-xcrossing-event-y "xlib-xr")
(autoload 'X-Event-xcrossing-state "xlib-xr")
(autoload 'X-Event-xcrossing-mode "xlib-xr")
(autoload 'X-Event-xcrossing-same-screen-focus "xlib-xr")
(autoload 'X-Event-xfocus-event "xlib-xr")
(autoload 'X-Event-xfocus-mode "xlib-xr")
(autoload 'X-Event-xexpose-window "xlib-xr")
(autoload 'X-Event-xexpose-x "xlib-xr")
(autoload 'X-Event-xexpose-y "xlib-xr")
(autoload 'X-Event-xexpose-width "xlib-xr")
(autoload 'X-Event-xexpose-height "xlib-xr")
(autoload 'X-Event-xexpose-count "xlib-xr")
(autoload 'X-Event-xgraphicsexpose-drawable "xlib-xr")
(autoload 'X-Event-xgraphicsexpose-x "xlib-xr")
(autoload 'X-Event-xgraphicsexpose-y "xlib-xr")
(autoload 'X-Event-xgraphicsexpose-width "xlib-xr")
(autoload 'X-Event-xgraphicsexpose-height "xlib-xr")
(autoload 'X-Event-xgraphicsexpose-minor-event "xlib-xr")
(autoload 'X-Event-xgraphicsexpose-count "xlib-xr")
(autoload 'X-Event-xgraphicsexpose-major-event "xlib-xr")
(autoload 'X-Event-xnoexpose-drawable "xlib-xr")
(autoload 'X-Event-xnoexpose-minor-event "xlib-xr")
(autoload 'X-Event-xnoexpose-major-event "xlib-xr")
(autoload 'X-Event-xvisibility-window "xlib-xr")
(autoload 'X-Event-xvisibility-state "xlib-xr")
(autoload 'X-Event-xcreatewindow-parent "xlib-xr")
(autoload 'X-Event-xcreatewindow-window "xlib-xr")
(autoload 'X-Event-xcreatewindow-x "xlib-xr")
(autoload 'X-Event-xcreatewindow-y "xlib-xr")
(autoload 'X-Event-xcreatewindow-width "xlib-xr")
(autoload 'X-Event-xcreatewindow-height "xlib-xr")
(autoload 'X-Event-xcreatewindow-border-width "xlib-xr")
(autoload 'X-Event-xcreatewindow-override "xlib-xr")
(autoload 'X-Event-xdestroywindow-event "xlib-xr")
(autoload 'X-Event-xdestroywindow-window "xlib-xr")
(autoload 'X-Event-xunmap-window "xlib-xr")
(autoload 'X-Event-xunmap-fromconfigure "xlib-xr")
(autoload 'X-Event-xmap-event "xlib-xr")
(autoload 'X-Event-xmap-window "xlib-xr")
(autoload 'X-Event-xmap-override "xlib-xr")
(autoload 'X-Event-xmaprequest-parent "xlib-xr")
(autoload 'X-Event-xmaprequest-window "xlib-xr")
(autoload 'X-Event-xreparent-event "xlib-xr")
(autoload 'X-Event-xreparent-window "xlib-xr")
(autoload 'X-Event-xreparent-parent "xlib-xr")
(autoload 'X-Event-xreparent-x "xlib-xr")
(autoload 'X-Event-xreparent-y "xlib-xr")
(autoload 'X-Event-xreparent-override "xlib-xr")
(autoload 'X-Event-xconfigure-event "xlib-xr")
(autoload 'X-Event-xconfigure-window "xlib-xr")
(autoload 'X-Event-xconfigure-above-sibling "xlib-xr")
(autoload 'X-Event-xconfigure-x "xlib-xr")
(autoload 'X-Event-xconfigure-y "xlib-xr")
(autoload 'X-Event-xconfigure-width "xlib-xr")
(autoload 'X-Event-xconfigure-height "xlib-xr")
(autoload 'X-Event-xconfigure-border-width "xlib-xr")
(autoload 'X-Event-xconfigure-override-redirect "xlib-xr")
(autoload 'X-Event-xconfigurerequest-parent "xlib-xr")
(autoload 'X-Event-xconfigurerequest-window "xlib-xr")
(autoload 'X-Event-xconfigurerequest-sibling "xlib-xr")
(autoload 'X-Event-xconfigurerequest-x "xlib-xr")
(autoload 'X-Event-xconfigurerequest-y "xlib-xr")
(autoload 'X-Event-xconfigurerequest-width "xlib-xr")
(autoload 'X-Event-xconfigurerequest-height "xlib-xr")
(autoload 'X-Event-xconfigurerequest-border-width "xlib-xr")
(autoload 'X-Event-xconfigurerequest-value-mask "xlib-xr")
(autoload 'X-Event-xgravity-event "xlib-xr")
(autoload 'X-Event-xgravity-window "xlib-xr")
(autoload 'X-Event-xgravity-x "xlib-xr")
(autoload 'X-Event-xgravity-y "xlib-xr")
(autoload 'X-Event-xresizerequest-window "xlib-xr")
(autoload 'X-Event-xresizerequest-width "xlib-xr")
(autoload 'X-Event-xresizerequest-height "xlib-xr")
(autoload 'X-Event-xcirculate-event "xlib-xr")
(autoload 'X-Event-xcirculate-window "xlib-xr")
(autoload 'X-Event-xcirculate-parent "xlib-xr")
(autoload 'X-Event-xcirculate-place "xlib-xr")
(autoload 'X-Event-xproperty-window "xlib-xr")
(autoload 'X-Event-xproperty-atom "xlib-xr")
(autoload 'X-Event-xproperty-time "xlib-xr")
(autoload 'X-Event-xproperty-state "xlib-xr")
(autoload 'X-Event-xselectionclear-time "xlib-xr")
(autoload 'X-Event-xselectionclear-window "xlib-xr")
(autoload 'X-Event-xselectionclear-atom "xlib-xr")
(autoload 'X-Event-xselectionrequest-time "xlib-xr")
(autoload 'X-Event-xselectionrequest-owner "xlib-xr")
(autoload 'X-Event-xselectionrequest-requestor "xlib-xr")
(autoload 'X-Event-xselectionrequest-selection "xlib-xr")
(autoload 'X-Event-xselectionrequest-target "xlib-xr")
(autoload 'X-Event-xselectionrequest-property "xlib-xr")
(autoload 'X-Event-xselection-time "xlib-xr")
(autoload 'X-Event-xselection-requestor "xlib-xr")
(autoload 'X-Event-xselection-selection "xlib-xr")
(autoload 'X-Event-xselection-target "xlib-xr")
(autoload 'X-Event-xselection-property "xlib-xr")
(autoload 'X-Event-xcolormap-window "xlib-xr")
(autoload 'X-Event-xcolormap-colormap "xlib-xr")
(autoload 'X-Event-xcolormap-new "xlib-xr")
(autoload 'X-Event-xcolormap-state "xlib-xr")
(autoload 'X-Event-xclient-window "xlib-xr")
(autoload 'X-Event-xclient-atom "xlib-xr")
(autoload 'X-Event-xclient-msg "xlib-xr")
(autoload 'X-Event-xmapping-request "xlib-xr")
(autoload 'X-Event-xmapping-first-keycode "xlib-xr")
(autoload 'X-Event-xmapping-count "xlib-xr")
(autoload 'X-Event-xerror-code "xlib-xr")
(autoload 'X-Event-xerror-resourceid "xlib-xr")
(autoload 'X-Event-xerror-min-op "xlib-xr")
(autoload 'X-Event-xerror-maj-op "xlib-xr")

(defconst X-connect-response (list [1 success] (list [1 length-1] [2 integerp] [2 integerp] [2 length-2] [length-1 stringp] [(X-mod-4 length-1) nil]) (list [1 nil] [2 integerp] [2 integerp] [2 length-1] [4 integerp] [4 integerp] [4 integerp] [4 integerp] [2 length-2] [2 integerp] [1 length-4] [1 length-3] [1 integerp] [1 integerp] [1 integerp] [1 integerp] [1 integerp] [1 integerp] [4 nil] [length-2 stringp] [(X-mod-4 length-2) nil] [length-3 ([1 integerp] [1 integerp] [1 integerp] [5 nil])] [length-4 ([4 integerp] [4 integerp] [4 integerp] [4 integerp] [4 integerp] [2 integerp] [2 integerp] [2 integerp] [2 integerp] [2 integerp] [2 integerp] [4 integerp] [1 integerp] [1 booleanp] [1 integerp] [1 length-1] [length-1 ([1 integerp] [1 nil] [2 length-1] [4 nil] [length-1 ([4 integerp] [1 integerp] [1 integerp] [2 integerp] [4 integerp] [4 integerp] [4 integerp] [4 nil])])])])) "\
Connection response structure.")

(autoload 'X-Dpy-read-excursion "xlib-xr" "\
Execute FORMS in reading mode." nil 'macro)

(autoload 'X-Dpy-events-excursion "xlib-xr" "\
Execute FORMS in safe manner." nil 'macro)

(autoload 'X-Dpy-send-excursion "xlib-xr" "\
Send all requests that appears in FORMS at once to X server.
Returns what FORMS returns.
Useful for drawing purposes." nil 'macro)

(autoload 'X-Generic-enqueue "xlib-xr" "\
Enqueue object QBJ into setf'able QUEUE." nil 'macro)

(autoload 'X-Dpy-parse-message "xlib-xr" "\
Receive (via filter and waiting) a response from  the X server.
Parses MESSAGE-S structure.  When MAY-GUESS is t then if 1st el is not 1 or 0,
we must process as an event instead.  Then keep looping on guess until we get
a 0 or 1.  If not, then we are processing sub-lists.  Processing is done for
XDPY.  ARGLIST is some list of arguments.

When FROM-X-PARSE-MESSAGE is non-nil than we are called from `X-Dpy-parse-message'.

MESSAGE-S is made of size vectors `X-Dpy-create-message':

  [SIZE ENCODING]

  SIZE is how many bytes it occupies in the message.
  ENCODING is how to interpret it.

  If encoding is 'success, then the following vectors are two lists.
The first is the Failure case.  nil is a generic failure.
The second is the Success case.

  Encoding can also be one of the following:
  nil      -- Not used
  integerp -- Format integer
  stringp  -- Formatted string
  length-# -- Number stored in variable `length-#' where # is 0-4.

The length-# variables are used to read a length from one section
of a message, and use it as the size field of a later occuring field.
A variable-length string can occur like this:

  [2 length-0]       ; length of string, does not appear in the list
  [length-0 stringp] ; name" nil nil)

;;;***

;;;### (autoloads (X-Generate-message X-Generic-p X-Generic-struct-p X-WMSize-p X-Text-width X-Text-height X-Text-descent X-Text-ascent X-Font-char-width X-Font-heigth X-Font-get X-Font-find X-Font-p X-Gc-message X-Gc-p X-Color-message X-Color-p X-Colormap-lookup-by-id X-Colormap-lookup-by-name X-Colormap-lookup-by-rgb X-Drawable-dpy X-Drawable-id X-Drawable-p X-Win-find-or-make X-Win-find X-Win-invalidate X-Conf-message X-Attr-message X-Attr-p X-Arc-message X-Rect-to-X-Geom X-Geom-to-X-Rect X-Geom-sub X-Geom-sum X-Geom-apply X-Geom-p X-Rect-message X-Rect-intersect-p X-Rect-internal-intersect-p X-Segment-message X-Point-message X-Point-y X-Point-x) "xlib-xwin" "lisp/xlib-xwin.el")

(autoload 'X-Point-x "xlib-xwin" nil nil 'macro)

(autoload 'X-Point-y "xlib-xwin" nil nil 'macro)

(autoload 'X-Point-message "xlib-xwin" "\
Return string representing x point XPNT." nil nil)

(autoload 'X-Segment-message "xlib-xwin" "\
Return string representing x segment XSEG." nil nil)

(defstruct (X-Rect (:predicate X-Rect-isrect-p)) x y width height)

(autoload 'X-Rect-internal-intersect-p "xlib-xwin" "\
Return non-nil if two rectangles XRECT1 and XRECT2 have common part." nil nil)

(autoload 'X-Rect-intersect-p "xlib-xwin" "\
Return non-nil if rectangles in XRECTS are intersects." nil nil)

(autoload 'X-Rect-message "xlib-xwin" "\
Return string representing X-Rect XRECT." nil nil)

(defstruct (X-Geom (:include X-Rect) (:predicate X-Geom-isgeom-p)) (border-width 0))

(autoload 'X-Geom-p "xlib-xwin" "\
Return non-nil if GEOM is X-Geom structure.
If SIG is gived and GEOM is not X-Geom structure, SIG will be signaled." nil nil)

(autoload 'X-Geom-apply "xlib-xwin" "\
Apply function FN to each element of GEOM1 and GEOM2.
Return new geom." nil nil)

(autoload 'X-Geom-sum "xlib-xwin" "\
Create new geometry which elements is sum of corresponded elements of GEOM1 and GEOM2." nil nil)

(autoload 'X-Geom-sub "xlib-xwin" nil nil nil)

(autoload 'X-Geom-to-X-Rect "xlib-xwin" "\
Convert XGEOM to X-Rect." nil nil)

(autoload 'X-Rect-to-X-Geom "xlib-xwin" "\
Convert XRECT to X-Geom." nil nil)

(defstruct (X-Arc (:include X-Rect) (:predicate X-Arc-isarc-p)) angle1 angle2)

(autoload 'X-Arc-message "xlib-xwin" "\
Return string representing XARC." nil nil)

(defstruct (X-Atom (:predicate X-Atom-isatom-p)) dpy id name)

(defstruct (X-Attr (:predicate X-Attr-isattr-p)) dpy id background-pixmap background-pixel border-pixmap border-pixel bit-gravity win-gravity backing-store backing-planes backing-pixel override-redirect save-under event-mask do-not-propagate-mask colormap cursor visualid mapstate (list '(((lambda (attr) (if (X-Pixmap-p (X-Attr-background-pixmap attr)) (X-Pixmap-id (X-Attr-background-pixmap attr)) (X-Attr-background-pixmap attr))) . 4) ((lambda (attr) (if (X-Color-p (X-Attr-background-pixel attr)) (X-Color-id (X-Attr-background-pixel attr)) (X-Attr-background-pixel attr))) . 4) ((lambda (attr) (if (X-Pixmap-p (X-Attr-border-pixmap attr)) (X-Pixmap-id (X-Attr-border-pixmap attr)) (X-Attr-border-pixmap attr))) . 4) ((lambda (attr) (if (X-Color-p (X-Attr-border-pixel attr)) (X-Color-id (X-Attr-border-pixel attr)) (X-Attr-border-pixel attr))) . 4) (X-Attr-bit-gravity . 1) (X-Attr-win-gravity . 1) (X-Attr-backing-store . 1) (X-Attr-backing-planes . 4) ((lambda (attr) (if (X-Color-p (X-Attr-backing-pixel attr)) (X-Color-id (X-Attr-backing-pixel attr)) (X-Attr-backing-pixel attr))) . 4) (X-Attr-override-redirect . 1) (X-Attr-save-under . 1) (X-Attr-event-mask . 4) (X-Attr-do-not-propagate-mask . 4) ((lambda (attr) (if (X-Colormap-p (X-Attr-colormap attr)) (X-Colormap-id (X-Attr-colormap attr)) (X-Attr-colormap attr))) . 4) ((lambda (attr) (if (X-Cursor-p (X-Attr-cursor attr)) (X-Cursor-id (X-Attr-cursor attr)) (X-Attr-cursor attr))) . 4))))

(autoload 'X-Attr-p "xlib-xwin" "\
Return non-nil if ATTR is attributes structure.
If SIG is given and ATTR is not attributes structure, SIG will be signaled." nil nil)

(autoload 'X-Attr-message "xlib-xwin" "\
Return a string representing the attributes ATTR." nil nil)

(defstruct (X-Conf (:predicate X-Conf-isconf-p)) dpy id x y width height border-width sibling stackmode (list '((X-Conf-x . 2) (X-Conf-y . 2) (X-Conf-width . 2) (X-Conf-height . 2) (X-Conf-border-width . 2) ((lambda (conf) (if (X-Win-p (X-Conf-sibling conf)) (X-Win-id (X-Conf-sibling conf)) (X-Conf-sibling conf))) . 4) (X-Conf-stackmode . 1))))

(autoload 'X-Conf-message "xlib-xwin" "\
Return a string representing the configuration CONF." nil nil)

(defstruct (X-Win (:predicate X-Win-iswin-p)) dpy id event-handlers plist)

(autoload 'X-Win-invalidate "xlib-xwin" "\
Remove WIN from dpy list and invalidate cl struct." nil nil)

(autoload 'X-Win-find "xlib-xwin" "\
Find X-Win with id WID on XDPY." nil nil)

(autoload 'X-Win-find-or-make "xlib-xwin" "\
Find X-Win with id WID on display XDPY, or make new one if not found." nil nil)

(defstruct (X-Pixmap (:predicate X-Pixmap-ispixmap-p)) dpy id plist)

(autoload 'X-Drawable-p "xlib-xwin" "\
Return non-nil if D is drawable.
If SIG, then signal on error." nil nil)

(autoload 'X-Drawable-id "xlib-xwin" "\
Return id of drawable D." nil nil)

(autoload 'X-Drawable-dpy "xlib-xwin" "\
Return dpy of drawable D." nil nil)

(defstruct (X-Colormap (:predicate X-Colormap-iscmap-p)) dpy id colors)

(autoload 'X-Colormap-lookup-by-rgb "xlib-xwin" "\
Lookup color in colormap CMAP by R G B values of X-Color COL." nil nil)

(autoload 'X-Colormap-lookup-by-name "xlib-xwin" "\
Lookup in CMAP color cache color named by COLOR-NAME." nil nil)

(autoload 'X-Colormap-lookup-by-id "xlib-xwin" "\
Lookup color in colormap CMAP by ID." nil nil)

(defstruct (X-Color (:predicate X-Color-iscolor-p)) dpy id cmap red green blue name flags)

(autoload 'X-Color-p "xlib-xwin" nil nil nil)

(autoload 'X-Color-message "xlib-xwin" "\
Convert COL into X request message." nil nil)

(defstruct (X-Gc (:predicate X-Gc-isgc-p)) dpy id style function plane-mask foreground background line-width line-style cap-style join-style fill-style fill-rule tile stipple tile-stipple-x-origin tile-stipple-y-origin font subwindow-mode graphics-exposures clip-x-origin clip-y-origin clip-mask dash-offset dashes arc-mode (list '((X-Gc-function . 1) (X-Gc-plane-mask . 4) ((lambda (gc) (if (X-Color-p (X-Gc-foreground gc)) (X-Color-id (X-Gc-foreground gc)) (X-Gc-foreground gc))) . 4) ((lambda (gc) (if (X-Color-p (X-Gc-background gc)) (X-Color-id (X-Gc-background gc)) (X-Gc-background gc))) . 4) (X-Gc-line-width . 2) (X-Gc-line-style . 1) (X-Gc-cap-style . 1) (X-Gc-join-style . 1) (X-Gc-fill-style . 1) (X-Gc-fill-rule . 1) (X-Gc-tile . 4) (X-Gc-stipple . 4) (X-Gc-tile-stipple-x-origin . 2) (X-Gc-tile-stipple-y-origin . 2) ((lambda (gc) (if (X-Font-p (X-Gc-font gc)) (X-Font-id (X-Gc-font gc)) (X-Gc-font gc))) . 4) (X-Gc-subwindow-mode . 1) (X-Gc-graphics-exposures . 1) (X-Gc-clip-x-origin . 2) (X-Gc-clip-y-origin . 2) ((lambda (gc) (if (X-Pixmap-p (X-Gc-clip-mask gc)) (X-Pixmap-id (X-Gc-clip-mask gc)) (X-Gc-clip-mask gc))) . 4) (X-Gc-dash-offset . 2) (X-Gc-dashes . 1) (X-Gc-arc-mode . 1))))

(autoload 'X-Gc-p "xlib-xwin" nil nil nil)

(autoload 'X-Gc-message "xlib-xwin" "\
Convert GC into message string." nil nil)

(defstruct (X-CharInfo (:predicate X-CharInfo-ischarinfo-p)))

(defstruct (X-Font (:predicate X-Font-isfont-p)) dpy id name minb maxb micob macob defchar nprops dd minbyte maxbyte allce fontascent fontdescent ncinfo props chinfo)

(autoload 'X-Font-p "xlib-xwin" nil nil nil)

(autoload 'X-Font-find "xlib-xwin" "\
Find font with id FID on X display XDPY." nil nil)

(autoload 'X-Font-get "xlib-xwin" "\
Get font by its name FNAME on display XDPY." nil nil)

(autoload 'X-Font-heigth "xlib-xwin" "\
Return FONT height." nil nil)

(autoload 'X-Font-char-width "xlib-xwin" "\
Return CHR width for FONT." nil nil)

(autoload 'X-Text-ascent "xlib-xwin" "\
Return overall TEXT's ascent.
If FONT-ASC is non-nil, return FONT's ascent." nil nil)

(autoload 'X-Text-descent "xlib-xwin" "\
Return overall TEXT's descent.
If FONT-DESC is non-nil, return FONT's descent." nil nil)

(autoload 'X-Text-height "xlib-xwin" "\
Return TEXT height for FONT." nil nil)

(autoload 'X-Text-width "xlib-xwin" "\
Return width of TEXT when it will be displayed in FONT." nil nil)

(defstruct (X-Cursor (:predicate X-Cursor-iscursor-p)) dpy id source mask src-char msk-char fgred fggreen fgblue bgred bggreen bgblue (list '(((lambda (curs) (if (X-Font-p (X-Cursor-source curs)) (X-Font-id (X-Cursor-source curs)) (X-Cursor-source curs))) . 4) ((lambda (curs) (if (X-Font-p (X-Cursor-mask curs)) (X-Font-id (X-Cursor-mask curs)) (X-Cursor-mask curs))) . 4) (X-Cursor-src-char . 2) (X-Cursor-msk-char . 2) (X-Cursor-fgred . 2) (X-Cursor-fggreen . 2) (X-Cursor-fgblue . 2) (X-Cursor-bgred . 2) (X-Cursor-bggreen . 2) (X-Cursor-bgblue . 2))))

(defstruct (X-WMSize (:predicate X-WMSize-issize-p)) flags x y width height min-width min-height max-width max-height width-inc height-inc min-aspect-x min-aspect-y max-aspect-x max-aspect-y base-width base-height gravity)

(autoload 'X-WMSize-p "xlib-xwin" nil nil nil)

(defstruct (X-WMHints (:predicate X-WMHints-ishints-p)) flags input initial-state icon-pixmap icon-window icon-x icon-y icon-mask window-group)

(autoload 'X-Generic-struct-p "xlib-xwin" "\
Return non-nil if GSTRUCT is generic struct which have id field." nil nil)

(autoload 'X-Generic-p "xlib-xwin" "\
Returns non-nil if THING is of TYPE, using predicate PFUNC.
If SIG is given, then signal if error." nil nil)

(autoload 'X-Generate-message "xlib-xwin" "\
Convert the attribute structure ATTR to a string.
The string is the message starting with VALUE_MASK, needed for
variable length requests, and the LISTofVALUE parts, depending if
those parts have been set.
Optional BITMASK-SIZE determines how much space is used by the bitmask
used in the message.  If it is excluded, then it defaults to 4." nil nil)

;;;***

(provide 'xlib-autoloads)
